@@ -14,6 +14,7 @@ from django.test import TestCase, override_settings
 from django.utils.timezone import is_aware, utc
 
 from storages.backends import s3boto3
+from tests.utils import NonSeekableContentFile
 
 
 class S3ManifestStaticStorageTestStorage(s3boto3.S3ManifestStaticStorage):
@@ -21,18 +22,6 @@ class S3ManifestStaticStorageTestStorage(s3boto3.S3ManifestStaticStorage):
         return None
 
 
-class NonSeekableContentFile(ContentFile):
-
-    def open(self, mode=None):
-        return self
-
-    def seekable(self):
-        return False
-
-    def seek(self, pos, whence=0):
-        raise AttributeError()
-
-
 class S3Boto3StorageTests(TestCase):
     def setUp(self):
         self.storage = s3boto3.S3Boto3Storage()
@@ -132,7 +121,8 @@ class S3Boto3StorageTests(TestCase):
             content,
             ExtraArgs={
                 'ContentType': 'text/plain',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_non_seekable(self):
@@ -149,7 +139,8 @@ class S3Boto3StorageTests(TestCase):
             content,
             ExtraArgs={
                 'ContentType': 'text/plain',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_with_default_acl(self):
@@ -168,7 +159,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'text/plain',
                 'ACL': 'private',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_object_parameters_not_overwritten_by_default(self):
@@ -188,7 +180,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'text/plain',
                 'ACL': 'private',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_content_type(self):
@@ -206,7 +199,8 @@ class S3Boto3StorageTests(TestCase):
             content,
             ExtraArgs={
                 'ContentType': 'image/jpeg',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_gzipped(self):
@@ -222,7 +216,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'application/octet-stream',
                 'ContentEncoding': 'gzip',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_gzipped_non_seekable(self):
@@ -238,7 +233,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'application/octet-stream',
                 'ContentEncoding': 'gzip',
-            }
+            },
+            Config=self.storage._transfer_config
         )
 
     def test_storage_save_gzip(self):
@@ -255,7 +251,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'text/css',
                 'ContentEncoding': 'gzip',
-            }
+            },
+            Config=self.storage._transfer_config
         )
         args, kwargs = obj.upload_fileobj.call_args
         content = args[0]
@@ -282,7 +279,8 @@ class S3Boto3StorageTests(TestCase):
             ExtraArgs={
                 'ContentType': 'text/css',
                 'ContentEncoding': 'gzip',
-            }
+            },
+            Config=self.storage._transfer_config
         )
         args, kwargs = obj.upload_fileobj.call_args
         content = args[0]
@@ -488,15 +486,25 @@ class S3Boto3StorageTests(TestCase):
 
     def test_storage_exists_false(self):
         self.storage.connection.meta.client.head_object.side_effect = ClientError(
-            {'Error': {'Code': '404', 'Message': 'Not Found'}},
+            {'Error': {}, 'ResponseMetadata': {'HTTPStatusCode': 404}},
             'HeadObject',
         )
-        self.assertFalse(self.storage.exists("file.txt"))
+        self.assertFalse(self.storage.exists('file.txt'))
         self.storage.connection.meta.client.head_object.assert_called_with(
             Bucket=self.storage.bucket_name,
             Key='file.txt',
         )
 
+    def test_storage_exists_other_error_reraise(self):
+        self.storage.connection.meta.client.head_object.side_effect = ClientError(
+            {'Error': {}, 'ResponseMetadata': {'HTTPStatusCode': 403}},
+            'HeadObject',
+        )
+        with self.assertRaises(ClientError) as cm:
+            self.storage.exists('file.txt')
+
+        self.assertEqual(cm.exception.response['ResponseMetadata']['HTTPStatusCode'], 403)
+
     def test_storage_delete(self):
         self.storage.delete("path/to/file.txt")
         self.storage.bucket.Object.assert_called_with('path/to/file.txt')
